/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.fabric8.kubernetes.examples.kubectl.equivalents;

import io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinition;
import io.fabric8.kubernetes.client.DefaultKubernetesClient;
import io.fabric8.kubernetes.client.KubernetesClient;

/**
 * This example is Java equivalent to `kubectl create -f test-crd.yaml`. It applies
 * the specified CustomResourceDefinition to cluster. You need to have cluster-admin
 * privileges in order to apply this.
 */
public class LoadAndCreateCustomResourceDefinition {
  public static void main(String[] args) {
    try (final KubernetesClient k8s = new DefaultKubernetesClient()) {
      CustomResourceDefinition crd = k8s.apiextensions().v1()
        .customResourceDefinitions()
        .load(LoadAndCreateCustomResourceDefinition.class.getResourceAsStream("/test-crd.yaml"))
        .get();

      k8s.apiextensions().v1().customResourceDefinitions().create(crd);
    }
  }
}
